@@ -526,6 +526,11 @@ class GenericJob(JobCore):
         Returns:
             GenericJob: GenericJob object pointing to the new location.
         """
+        # Update flags
+        if input_only and new_database_entry:
+            warnings.warn("input_only conflicts new_database_entry; setting new_database_entry=False")
+            new_database_entry = False
+
         # Call the copy_to() function defined in the JobCore
         new_job_core, file_project, hdf5_project, reloaded = self._internal_copy_to(
             project=project,
@@ -534,6 +539,13 @@ class GenericJob(JobCore):
             copy_files=False,
             delete_existing_job=delete_existing_job
         )
+
+        # Remove output if it should not be copied
+        if input_only:
+            for group in new_job_core.project_hdf5.list_groups():
+                if "output" in group:
+                    del new_job_core.project_hdf5[posixpath.join(new_job_core.project_hdf5.h5_path, group)]
+            new_job_core.status.initialized = True
         new_job_core._after_generic_copy_to(self, new_database_entry=new_database_entry, reloaded=reloaded)
         return new_job_core
 
@@ -1033,18 +1045,6 @@ class GenericJob(JobCore):
         job._init_child_job(self)
         return job
 
-    def create_pipeline(self, step_lst, delete_existing_job=False):
-        """
-        Create a job pipeline
-
-        Args:
-            step_lst (list): List of functions which create calculations
-
-        Returns:
-            FlexibleMaster:
-        """
-        return self.project.create_pipeline(job=self, step_lst=step_lst, delete_existing_job=delete_existing_job)
-
     def update_master(self):
         """
         After a job is finished it checks whether it is linked to any metajob - meaning the master ID is pointing to
